<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <location filename="src/aboutview.cpp" line="58"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Existe vida para além do navegador!</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="59"/>
        <source>Version %1</source>
        <translation>Versão %1</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="64"/>
        <source>Licensed to: %1</source>
        <translation>Licenciado a: %1</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="68"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 é um programa livre mas o seu desenvolvimento ocupa tempo precioso.</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="69"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Efetue um&lt;a href=&apos;%1&apos;&gt;donativo&lt;/a&gt; para ajudar no desenvolvimento do %2.</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="73"/>
        <source>You may want to try my other apps as well:</source>
        <translation>Também pode experimentar as minhas outras aplicações:</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="76"/>
        <source>%1, a YouTube music player</source>
        <translation>%1, um leitor de música YouTube</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="80"/>
        <source>%1, a music player</source>
        <translation>%1, um reprodutor de músicas</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="86"/>
        <source>Translate %1 to your native language using %2</source>
        <translation>Ajude a traduzir o %1 através do %2</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="91"/>
        <source>Icon designed by %1.</source>
        <translation>Ícone criado por %1.</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="95"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Disponibilizado nos ternmos da &lt;a href=&apos;&quot;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="src/aboutview.cpp" line="110"/>
        <source>&amp;Close</source>
        <translation>Fe&amp;char</translation>
    </message>
    <message>
        <location filename="src/aboutview.h" line="40"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <location filename="local/src/activationdialog.cpp" line="17"/>
        <source>Enter your License Details</source>
        <translation>Introduza os detalhes da licença</translation>
    </message>
    <message>
        <location filename="local/src/activationdialog.cpp" line="29"/>
        <source>&amp;Email:</source>
        <translation>&amp;Endereço eletrónico:</translation>
    </message>
    <message>
        <location filename="local/src/activationdialog.cpp" line="35"/>
        <source>&amp;Code:</source>
        <translation>&amp;Código:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <location filename="local/src/activationview.cpp" line="47"/>
        <source>Please license %1</source>
        <translation>Por favor licencie o %1</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="51"/>
        <source>This demo has expired.</source>
        <translation>Esta demo expirou.</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="53"/>
        <source>The full version allows you to watch videos without interruptions.</source>
        <oldsource>The full version allows you to download videos longer than %1 minutes and to watch videos without interruptions.</oldsource>
        <translation>A versão compreta permite-lhe ver vídeos sem interrupções.</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="55"/>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Sem uma licença, esta apliacação expirará em %1 dias.</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="57"/>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ao comprar a versão completa, estará a ajudar no desenvolvimento do %1.</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="70"/>
        <source>Use Demo</source>
        <translation>Utilizar demo</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="77"/>
        <source>Enter License</source>
        <translation>Introduzir licença</translation>
    </message>
    <message>
        <location filename="local/src/activationview.cpp" line="85"/>
        <source>Buy License</source>
        <translation>Comprar licença</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <location filename="src/channelaggregator.cpp" line="183"/>
        <source>By %1</source>
        <translation>De %1</translation>
    </message>
    <message numerus="yes">
        <location filename="src/channelaggregator.cpp" line="185"/>
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <location filename="src/channelitemdelegate.cpp" line="67"/>
        <source>All Videos</source>
        <translation>Todos os vídeos</translation>
    </message>
    <message>
        <location filename="src/channelitemdelegate.cpp" line="85"/>
        <source>Unwatched Videos</source>
        <translation>Vídeos não vistos</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <location filename="src/channelview.cpp" line="151"/>
        <source>Mark all as watched</source>
        <translation>Marcar como visto</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="159"/>
        <source>Show Updated</source>
        <translation>Mostrar atualizados</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="103"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="110"/>
        <source>Last Updated</source>
        <translation>Última atualização</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="117"/>
        <source>Last Added</source>
        <translation>Última adição</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="124"/>
        <source>Last Watched</source>
        <translation>Últimos vistos</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="131"/>
        <source>Most Watched</source>
        <translation>Mais vistos</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="139"/>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="222"/>
        <source>All Videos</source>
        <translation>Todos os vídeos</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="226"/>
        <source>Unwatched Videos</source>
        <translation>Vídeos não vistos</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="244"/>
        <source>Mark as Watched</source>
        <translation>Marcar como visto</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="257"/>
        <source>Unsubscribe</source>
        <translation>Cancelar subscrição</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="270"/>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Não existem atualizações de subscrições.</translation>
    </message>
    <message>
        <location filename="src/channelview.cpp" line="272"/>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Ainda não possui subscrições. Utilize a estrela para subscrever os canais.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="src/exlineedit.cpp" line="6"/>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <location filename="src/datautils.cpp" line="88"/>
        <source>Just now</source>
        <translation>Agora mesmo</translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="90"/>
        <source>%n minute(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="92"/>
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="94"/>
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="96"/>
        <source>%n weeks(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <location filename="src/datautils.cpp" line="98"/>
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="src/downloaditem.cpp" line="406"/>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="409"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="412"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="421"/>
        <source>bytes/sec</source>
        <translation>bytes/seg</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="424"/>
        <source>KB/sec</source>
        <translation>KB/seg</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="427"/>
        <source>MB/sec</source>
        <translation>MB/seg</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="433"/>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="436"/>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="439"/>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restante</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="src/downloadmanager.cpp" line="77"/>
        <source>This is just the demo version of %1.</source>
        <translation>Esta é uma versão de demonstração do %1.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="79"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Apenas pode transferir vídeos mais curtos que %1 minuto(s) de forma a testar a funcionalidade de transferência.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="85"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="86"/>
        <source>Get the full version</source>
        <translation>Obter a versão completa</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="157"/>
        <source>%1 downloaded in %2</source>
        <translation>%1 transferência em %2</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="160"/>
        <source>Download finished</source>
        <translation>Transferência terminada</translation>
    </message>
    <message numerus="yes">
        <location filename="src/downloadmanager.cpp" line="165"/>
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="src/downloadsettings.cpp" line="36"/>
        <source>Change location...</source>
        <translation>Mudar localização...</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="69"/>
        <source>Choose the download location</source>
        <translation>Escolha a localização da transferência</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="81"/>
        <source>Download location changed.</source>
        <translation>Localização alterada.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="83"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>As transferências atuais serão colocadas na localização anterior.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="94"/>
        <source>Downloading to: %1</source>
        <translation>Transferência em: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="src/downloadview.cpp" line="38"/>
        <location filename="src/downloadview.h" line="45"/>
        <source>Downloads</source>
        <translation>Transferências</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <location filename="local/src/updatedialog.cpp" line="60"/>
        <source>Downloading update...</source>
        <translation>Transferência da atualizaçao...</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <location filename="local/src/extra.cpp" line="251"/>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>O arquivo executável foi temperada com, talvez por um vírus.</translation>
    </message>
    <message>
        <location filename="local/src/extra.cpp" line="252"/>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 não será executado. Tente instalar novamente.</translation>
    </message>
    <message>
        <location filename="local/src/extra.cpp" line="253"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="local/src/extra.cpp" line="254"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="src/globalshortcuts.cpp" line="36"/>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="37"/>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="38"/>
        <source>Play/Pause</source>
        <translation>Reproduzir/Pausa</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="39"/>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="40"/>
        <source>Stop playing after current track</source>
        <translation>Parar reprodução após a faixa atual</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="41"/>
        <source>Next track</source>
        <translation>Próxima faixa</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="42"/>
        <source>Previous track</source>
        <translation>Faixa anterior</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="43"/>
        <source>Increase volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="44"/>
        <source>Decrease volume</source>
        <translation>Diminuir volume</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="45"/>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="46"/>
        <source>Seek forward</source>
        <translation>Avançar</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="47"/>
        <source>Seek backward</source>
        <translation>Recuar</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <location filename="src/homeview.cpp" line="58"/>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="60"/>
        <source>Find videos and channels by keyword</source>
        <translation>Localizar vídeos de canais por palavra-chave</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="65"/>
        <source>Browse</source>
        <translation>Explorar</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="67"/>
        <source>Browse videos by category</source>
        <translation>Explorar vídeos por categoria</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="71"/>
        <source>Subscriptions</source>
        <translation>Subscrições</translation>
    </message>
    <message>
        <location filename="src/homeview.cpp" line="73"/>
        <source>Channel subscriptions</source>
        <translation>Subscrições de canais</translation>
    </message>
    <message>
        <location filename="src/homeview.h" line="44"/>
        <source>Make yourself comfortable</source>
        <translation>Ponha-se confortável</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="src/loadingwidget.cpp" line="125"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/mainwindow.cpp" line="291"/>
        <source>&amp;Stop</source>
        <translation>Para&amp;r</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="292"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Parar reprodução e voltar à vista de procura</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="307"/>
        <source>S&amp;kip</source>
        <translation>I&amp;gnorar</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="308"/>
        <source>Skip to the next video</source>
        <translation>Ir para o próximo vídeo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1134"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1135"/>
        <source>Pause playback</source>
        <translation>Pausar reprodução</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="321"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Ecrã completo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="322"/>
        <source>Go full screen</source>
        <translation>Modo de ecrã completo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="336"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ocultar lista de reprodução e barra de ferramentas</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="349"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir para a página do Youtube e parar a reprodução</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="356"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar ligação do atual vídeo Youtube para a área de transferência</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="363"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar URL da emissão atual para a área de transferência</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="370"/>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Localizar outras partes do vídeo pela ordem correta</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="376"/>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="377"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Remover os vídeos selecionados da lista de reprodução</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="383"/>
        <source>Move &amp;Up</source>
        <translation>Mover para &amp;cima</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="384"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover para cima os vídeos selecionados</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="390"/>
        <source>Move &amp;Down</source>
        <translation>Mover para &amp;baixo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="391"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover para baixo os vídeos selecionados</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="402"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Limpar histório de procura. Não pode ser anulado.</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="407"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="410"/>
        <source>Bye</source>
        <translation>Adeus</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="414"/>
        <source>&amp;Website</source>
        <translation>Sítio &amp;web</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="416"/>
        <source>%1 on the Web</source>
        <translation>%1 na web</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="422"/>
        <source>Please support the continued development of %1</source>
        <translation>Por favor ajude no desenvolvimento do %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="427"/>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="429"/>
        <source>Info about %1</source>
        <translation>Informações de %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="437"/>
        <source>Search</source>
        <translation>Procura</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="456"/>
        <source>Mute volume</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="490"/>
        <location filename="src/mainwindow.cpp" line="1609"/>
        <source>&amp;Downloads</source>
        <translation>&amp;Transferências</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="491"/>
        <source>Show details about video downloads</source>
        <translation>Mostar detalhes sobre a transferência de vídeos</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="499"/>
        <source>&amp;Download</source>
        <translation>&amp;Transferência</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="500"/>
        <source>Download the current video</source>
        <translation>Transferir o vídeo atual</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="510"/>
        <source>Take &amp;Snapshot</source>
        <translation>Take &amp;Snapshot</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="517"/>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Subscrever o canal</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="525"/>
        <source>Share the current video using %1</source>
        <translation>Partilhar o atual vídeo através do %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="545"/>
        <source>&amp;Email</source>
        <translation>&amp;Endereço eletrónico</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="546"/>
        <source>Email</source>
        <translation>Endereço eletrónico</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="551"/>
        <source>&amp;Close</source>
        <translation>Fe&amp;char</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="561"/>
        <source>&amp;Float on Top</source>
        <translation>&amp;Flutuante na frente</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="566"/>
        <source>&amp;Adjust Window Size</source>
        <translation>&amp;Ajuste o tamanho da janela</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="571"/>
        <source>&amp;Stop After This Video</source>
        <translation>Parar após es&amp;te vídeo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="578"/>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Reportar um erro...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="582"/>
        <source>&amp;Refine Search...</source>
        <translation>Melhorar proc&amp;ura...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="594"/>
        <source>More...</source>
        <translation>Mais...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="597"/>
        <source>&amp;Related Videos</source>
        <translation>Vídeos &amp;relacionados</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="599"/>
        <source>Watch videos related to the current one</source>
        <translation>Ver vídeos relacionados com o atual</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="605"/>
        <source>Open in &amp;Browser...</source>
        <translation>A&amp;brir no navegador...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="612"/>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Gosta? %1? Avalie!</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="633"/>
        <source>&amp;Application</source>
        <translation>&amp;Aplicação</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="618"/>
        <source>Buy %1...</source>
        <translation>Comprar %1...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="647"/>
        <source>&amp;Playback</source>
        <translation>Reprod&amp;ução</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="661"/>
        <source>&amp;Playlist</source>
        <translation>Lista de re&amp;produção</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="670"/>
        <source>&amp;Video</source>
        <translation>Víd&amp;eo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="686"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="695"/>
        <source>&amp;Share</source>
        <translation>Partil&amp;har</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="709"/>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="751"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Prima %1 para aumentar o volume, %2 para o reduzir</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1021"/>
        <location filename="src/mainwindow.cpp" line="1027"/>
        <source>Opening %1</source>
        <translation>A abrir %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1080"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Deseja sair do %1 com uma transferência ativa?</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1081"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Se fechar o %1, a transferência irá ser cancelada.</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1086"/>
        <source>Close and cancel download</source>
        <translation>Fechar e cancelar transferência</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1087"/>
        <source>Wait for download to finish</source>
        <translation>Esperar pelo fim da transferência</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1158"/>
        <source>&amp;Loading...</source>
        <translation>&amp;Carregando...</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1264"/>
        <source>Leave &amp;Full Screen</source>
        <translation>Sair do modo de &amp;ecrã completo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1718"/>
        <source>%1 version %2 is now available.</source>
        <translation>Está disponível o %1 %2.</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1722"/>
        <source>Remind me later</source>
        <translation>Lembrar mais tarde</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1723"/>
        <source>Update</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1127"/>
        <source>Error: %1</source>
        <translation>Erro:%1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="300"/>
        <source>P&amp;revious</source>
        <translation>&amp;Anterior</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="301"/>
        <source>Go back to the previous track</source>
        <translation>Ir para a faixa anterior</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="335"/>
        <source>&amp;Compact Mode</source>
        <translation>Modo &amp;compacto</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="348"/>
        <source>Open the &amp;YouTube Page</source>
        <translation>Abrir a página &amp;YouTube</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="355"/>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Copiar &amp;ligação do YouTube</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="362"/>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Copiar &amp;URL da emissão</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="369"/>
        <source>Find Video &amp;Parts</source>
        <translation>Localizar &amp;partes do vídeo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="397"/>
        <source>&amp;Clear Recent Searches</source>
        <translation>Limpar procuras re&amp;centes</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="421"/>
        <source>Make a &amp;Donation</source>
        <translation>Efetuar &amp;donativo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="483"/>
        <source>&amp;Manually Start Playing</source>
        <translation>Iniciar reprodução &amp;manualmente</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="484"/>
        <source>Manually start playing videos</source>
        <translation>Iniciar reprodução de vídeos manualmente</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="847"/>
        <source>Choose your content location</source>
        <translation>Escolha a localização do conteúdo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="314"/>
        <location filename="src/mainwindow.cpp" line="1142"/>
        <location filename="src/mainwindow.cpp" line="1150"/>
        <source>&amp;Play</source>
        <translation>Re&amp;produzir</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="315"/>
        <location filename="src/mainwindow.cpp" line="1143"/>
        <location filename="src/mainwindow.cpp" line="1151"/>
        <source>Resume playback</source>
        <translation>Retomar reprodução</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1437"/>
        <source>Remaining time: %1</source>
        <translation>Tempo restante:%1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1528"/>
        <source>Volume at %1%</source>
        <translation>Volume:%1%</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1534"/>
        <source>Volume is muted</source>
        <translation>Volume nulo</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1537"/>
        <source>Volume is unmuted</source>
        <translation>Volume restaurado</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1548"/>
        <source>Maximum video definition set to %1</source>
        <translation>Definição máxima do vídeo definida para %1</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1595"/>
        <source>Your privacy is now safe</source>
        <translation>A sua privacidade está agora assegurada</translation>
    </message>
    <message>
        <location filename="src/mainwindow.cpp" line="1610"/>
        <source>Downloads complete</source>
        <translation>Transferências terminadas</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="src/mediaview.cpp" line="702"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Agora pode colar a ligação YouTube em qualquer outra aplicação</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="710"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Agora pode colar o URL do vídeo em qualquer outra aplicação</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="711"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>A ligação será válida por tempo limitado.</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="800"/>
        <source>This is just the demo version of %1.</source>
        <translation>Esta é uma versão de demonstração do %1.</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="801"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Permite-lhe testar ea aplicação e verificar se é do seu agrado.</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="833"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="988"/>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>de</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1001"/>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>parte</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1003"/>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episódio</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1096"/>
        <source>Sent from %1</source>
        <translation>Enviado de %1</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1128"/>
        <source>Unsubscribe from %1</source>
        <translation>Cancelar subscrição de %1</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1132"/>
        <source>Subscribe to %1</source>
        <translation>Subscrever %1</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1166"/>
        <source>Unsubscribed from %1</source>
        <translation>Não subscrito de %1</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="1169"/>
        <source>Subscribed to %1</source>
        <translation>Subscrito %1</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="808"/>
        <source>Get the full version</source>
        <translation>Obter a versão completa</translation>
    </message>
    <message>
        <location filename="src/mediaview.cpp" line="847"/>
        <source>Downloading %1</source>
        <translation>Transferência: %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <location filename="local/src/updatedialog.cpp" line="21"/>
        <source>A new version of %1 is available!</source>
        <translation>Está disponível uma nova versão do %1!</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="28"/>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>O %1 %2 está disponível. A sua versão é a %3.</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="33"/>
        <source>Would you like to download it now?</source>
        <translation>Gostaria de transferir a nova versão?</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="39"/>
        <source>Skip This Version</source>
        <translation>Ignorar esta versão</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="43"/>
        <source>Remind Me Later</source>
        <translation>Lembrar mais tarde</translation>
    </message>
    <message>
        <location filename="local/src/updatedialog.cpp" line="47"/>
        <source>Install Update</source>
        <translation>Instalar atualização</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <location filename="local/src/pastelineedit.cpp" line="6"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="209"/>
        <source>%1 views</source>
        <translation>%1 visualizações</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="309"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) — %4</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="316"/>
        <source>Preparing</source>
        <translation>Preparação</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="318"/>
        <source>Failed</source>
        <translation>Falha</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="320"/>
        <source>Completed</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="322"/>
        <source>Stopped</source>
        <translation>Parado</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="358"/>
        <source>Stop downloading</source>
        <translation>Parar transferência</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="368"/>
        <source>Show in %1</source>
        <translation>Mostrar em %1</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="370"/>
        <source>Open parent folder</source>
        <translation>Abrir pasta respetiva</translation>
    </message>
    <message>
        <location filename="src/playlistitemdelegate.cpp" line="379"/>
        <source>Restart downloading</source>
        <translation>Reiniciar transferência</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <location filename="src/playlistmodel.cpp" line="70"/>
        <source>Searching...</source>
        <translation>Procura...</translation>
    </message>
    <message>
        <location filename="src/playlistmodel.cpp" line="71"/>
        <source>Show %1 More</source>
        <translation>Mostrar mais %1</translation>
    </message>
    <message>
        <location filename="src/playlistmodel.cpp" line="72"/>
        <source>No videos</source>
        <translation>Nenhum vídeo</translation>
    </message>
    <message>
        <location filename="src/playlistmodel.cpp" line="73"/>
        <source>No more videos</source>
        <translation>Sem mais vídeos</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="49"/>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="53"/>
        <source>Relevance</source>
        <translation>Relevância</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="54"/>
        <location filename="src/refinesearchwidget.cpp" line="69"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="55"/>
        <source>View Count</source>
        <translation>Visualizações</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="56"/>
        <source>Rating</source>
        <translation>Avaliação</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="73"/>
        <source>Anytime</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="74"/>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="75"/>
        <source>7 Days</source>
        <translation>7 dias</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="76"/>
        <source>30 Days</source>
        <translation>30 dias</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="89"/>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="93"/>
        <location filename="src/refinesearchwidget.cpp" line="119"/>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="94"/>
        <source>Short</source>
        <translation>Curtos</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="95"/>
        <source>Medium</source>
        <translation>Normais</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="96"/>
        <source>Long</source>
        <translation>Longos</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="99"/>
        <source>Less than 4 minutes</source>
        <translation>Menos de 4 minutos</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="100"/>
        <source>Between 4 and 20 minutes</source>
        <translation>Entre 4 e 20 minutos</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="101"/>
        <source>Longer than 20 minutes</source>
        <translation>Mais do que 20 minutos</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="115"/>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="120"/>
        <source>High Definition</source>
        <translation>Alta definição</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="123"/>
        <source>720p or higher</source>
        <translation>720p ou mais</translation>
    </message>
    <message>
        <location filename="src/refinesearchwidget.cpp" line="136"/>
        <source>Done</source>
        <translation>Terminado</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <location filename="src/regionsview.cpp" line="39"/>
        <source>Done</source>
        <translation>Terminado</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="55"/>
        <source>Search</source>
        <translation>Procura</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="src/searchview.cpp" line="83"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bem-vindo ao &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="200"/>
        <source>Get the full version</source>
        <translation>Obter a versão completa</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="110"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole phrase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>Introduza</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="117"/>
        <source>a keyword</source>
        <translation>uma palavra-chave</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="118"/>
        <source>a channel</source>
        <translation>um canal</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="125"/>
        <source>to start watching videos.</source>
        <translation>para começar a visualizar os vídeos.</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="156"/>
        <source>Watch</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="174"/>
        <source>Recent keywords</source>
        <translation>Palavras-chave recentes</translation>
    </message>
    <message>
        <location filename="src/searchview.cpp" line="186"/>
        <source>Recent channels</source>
        <translation>Canais recentes</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <location filename="src/sidebarheader.cpp" line="38"/>
        <location filename="src/sidebarheader.cpp" line="45"/>
        <source>&amp;Back</source>
        <translation>&amp;Recuar</translation>
    </message>
    <message>
        <location filename="src/sidebarheader.cpp" line="76"/>
        <source>Forward to %1</source>
        <translation>Avançar para %1</translation>
    </message>
    <message>
        <location filename="src/sidebarheader.cpp" line="89"/>
        <source>Back to %1</source>
        <translation>Recuar para %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <location filename="src/sidebarwidget.cpp" line="68"/>
        <source>Refine Search</source>
        <translation>Melhorar procura</translation>
    </message>
    <message>
        <location filename="src/sidebarwidget.cpp" line="167"/>
        <source>Did you mean: %1</source>
        <translation>Será que queria dizer: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <location filename="src/snapshotsettings.cpp" line="47"/>
        <source>Change location...</source>
        <translation>Mudar localização...</translation>
    </message>
    <message>
        <location filename="src/snapshotsettings.cpp" line="64"/>
        <source>Snapshot saved to %1</source>
        <translation>Snapshot guardado em %1</translation>
    </message>
    <message>
        <location filename="src/snapshotsettings.cpp" line="117"/>
        <source>Snapshots location changed.</source>
        <translation>Localização dos snapshots alterada.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <location filename="src/standardfeedsview.cpp" line="107"/>
        <source>Most Popular</source>
        <translation>Mais populares</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="src/video.cpp" line="287"/>
        <source>Cannot get video stream for %1</source>
        <translation>Não é possível obter a emissão de %1</translation>
    </message>
    <message>
        <location filename="src/video.cpp" line="292"/>
        <source>Network error: %1 for %2</source>
        <translation>Erro de rede: %1 para %2</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <location filename="src/ytregions.cpp" line="28"/>
        <source>Algeria</source>
        <translation>Argélia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="29"/>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="30"/>
        <source>Australia</source>
        <translation>Austrália</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="31"/>
        <source>Belgium</source>
        <translation>Bélgica</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="32"/>
        <source>Brazil</source>
        <translation>Brasil</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="33"/>
        <source>Canada</source>
        <translation>Canadá</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="34"/>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="35"/>
        <source>Colombia</source>
        <translation>Colômbia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="36"/>
        <source>Czech Republic</source>
        <translation>República Checa</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="37"/>
        <source>Egypt</source>
        <translation>Egito</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="38"/>
        <source>France</source>
        <translation>França</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="39"/>
        <source>Germany</source>
        <translation>Alemanha</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="40"/>
        <source>Ghana</source>
        <translation>Gana</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="41"/>
        <source>Greece</source>
        <translation>Grécia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="42"/>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="43"/>
        <source>Hungary</source>
        <translation>Húngria</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="44"/>
        <source>India</source>
        <translation>Índia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="45"/>
        <source>Indonesia</source>
        <translation>Indonésia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="46"/>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="47"/>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="48"/>
        <source>Italy</source>
        <translation>Itália</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="49"/>
        <source>Japan</source>
        <translation>Japão</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="50"/>
        <source>Jordan</source>
        <translation>Jordânia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="51"/>
        <source>Kenya</source>
        <translation>Quénia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="52"/>
        <source>Malaysia</source>
        <translation>Malásia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="53"/>
        <source>Mexico</source>
        <translation>México</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="54"/>
        <source>Morocco</source>
        <translation>Marrocos</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="55"/>
        <source>Netherlands</source>
        <translation>Países Baixos</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="56"/>
        <source>New Zealand</source>
        <translation>Nova Zelândia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="57"/>
        <source>Nigeria</source>
        <translation>Nigéria</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="58"/>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="59"/>
        <source>Philippines</source>
        <translation>Filipinas</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="60"/>
        <source>Poland</source>
        <translation>Polónia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="61"/>
        <source>Russia</source>
        <translation>Rússia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="62"/>
        <source>Saudi Arabia</source>
        <translation>Arábia Saudita</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="63"/>
        <source>Singapore</source>
        <translation>Singapura</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="64"/>
        <source>South Africa</source>
        <translation>África do Sul</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="65"/>
        <source>South Korea</source>
        <translation>Coreia do Sul</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="66"/>
        <source>Spain</source>
        <translation>Espanha</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="67"/>
        <source>Sweden</source>
        <translation>Suécia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="68"/>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="69"/>
        <source>Tunisia</source>
        <translation>Tunísia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="70"/>
        <source>Turkey</source>
        <translation>Turquia</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="71"/>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="72"/>
        <source>United Arab Emirates</source>
        <translation>Emirados Árabes Unidos</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="73"/>
        <source>United Kingdom</source>
        <translation>Reino Unido</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="74"/>
        <source>Yemen</source>
        <translation>Íémen</translation>
    </message>
    <message>
        <location filename="src/ytregions.cpp" line="148"/>
        <source>Worldwide</source>
        <translation>Global</translation>
    </message>
</context>
</TS>